=========
nifigator
=========

This is the documentation of **nifigator**.

Contents
========

.. toctree::
   :maxdepth: 2

   Installation <readme>
   01_short_overview
   02_adding_document_data
   03_adding_annotations
   04_using a SPARQL endpoint
   05_using a NifVector graph - English
   05_using a NifVector graph - Dutch
   06_creating a nifvec graph
   07_Sentence similarities
   08_SPARQL queries for NifVector
   10_using_a_lemon_termbase
   Contributions & Help <contributing>
   License <license>
   Authors <authors>
   Changelog <changelog>
   Module Reference <api/modules>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _toctree: https://www.sphinx-doc.org/en/master/usage/restructuredtext/directives.html
.. _reStructuredText: https://www.sphinx-doc.org/en/master/usage/restructuredtext/basics.html
.. _references: https://www.sphinx-doc.org/en/stable/markup/inline.html
.. _Python domain syntax: https://www.sphinx-doc.org/en/master/usage/restructuredtext/domains.html#the-python-domain
.. _Sphinx: https://www.sphinx-doc.org/
.. _Python: https://docs.python.org/
